Learn R Programming

HTSeqGenie (version 3.18.0)

readRNASeqEnds: Read Paired End Bam Files

Description

Read paired end BAM files with requested columns from the BAM

Usage

readRNASeqEnds(bam_file, scan_bam_what = NULL, remove.strandness = TRUE)

Arguments

bam_file
Path to a bam file
scan_bam_what
additional paramters passed to scanBamParam()
remove.strandness
A logical indicating whether read strands should be set to "*".

Value

GRangesList

Details

This function returns a GRangesList containing information about pair-end alignment data. It is essentially Rsamtools::readGAlignments, but it uses Rsamtools::scanBam to get information that cannot be obtained from readBamGappedAlignments.